@@ -5,3 +5,7 @@ from strange_case.configurators import provides
 def setdefault_iterable(source_file, config):
     config['iterable'] = not config['is_index']
     return config
+
+setdefault_iterable.dont_inherit = [
+    'iterable'
+]
